dm: Rename 'platdata_size' to 'plat_size'

Rename this to be consistent with the change from 'platdata'.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/platdata.h b/include/dm/platdata.h
index 6094b66..d650fb3 100644
--- a/include/dm/platdata.h
+++ b/include/dm/platdata.h
@@ -21,14 +21,14 @@
  *
  * @name:	Driver name
  * @plat:	Driver-specific platform data
  * @platdata_size: Size of platform data structure
  * @parent_idx:	Index of the parent driver_info structure
  */
 struct driver_info {
 	const char *name;
 	const void *plat;
 #if CONFIG_IS_ENABLED(OF_PLATDATA)
-	unsigned short platdata_size;
+	unsigned short plat_size;
 	short parent_idx;
 #endif
 };
@@ -21,14 +21,14 @@
  * @name:	Driver name
  * @plat:	Driver-specific platform data
- * @platdata_size: Size of platform data structure
+ * @plat_size: Size of platform data structure
  * @parent_idx:	Index of the parent driver_info structure
  */